==> icinga-web2-module-director-1.4.3.tgz: icinga-web2/modules/director/library/Director/Web/Tabs/ImportsourceTabs.php <==
<?php

namespace Icinga\Module\Director\Web\Tabs;

use dipl\Translation\TranslationHelper;
use dipl\Web\Widget\Tabs;

class ImportsourceTabs extends Tabs
{
    use TranslationHelper;

    protected $id;

    public function __construct($id = null)
    {
        $this->id = $id;
        $this->assemble();
    }

    protected function assemble()
    {
        if ($id = $this->id) {
            $params = ['id' => $id];
            $this->add('index', [
                'url'       => 'director/importsource',
                'urlParams' => $params,
                'label'     => $this->translate('Import source'),
            ])->add('edit', [
                'url'       => 'director/importsource/edit',
                'urlParams' => $params,
                'label'     => $this->translate('Modify'),
            ])->add('modifier', [
                'url'       => 'director/importsource/modifier',
                'urlParams' => ['source_id' => $id],
                'label'     => $this->translate('Modifiers'),
            ])->add('history', [
                'url'       => 'director/importsource/history',
                'urlParams' => $params,
                'label'     => $this->translate('History'),
            ])->add('preview', [
                'url'       => 'director/importsource/preview',
                'urlParams' => $params,
                'label'     => $this->translate('Preview'),
            ]);
        } else {
            $this->add('add', [
                'url'   => 'director/importsource/add',
                'label' => $this->translate('New import source'),
            ])->activate('add');
        }
    }
}

==> icinga-web2-module-director-1.5.1.tgz: icinga-web2/modules/director/library/Director/Web/Tabs/ImportsourceTabs.php <==
<?php

namespace Icinga\Module\Director\Web\Tabs;

use dipl\Translation\TranslationHelper;
use dipl\Web\Widget\Tabs;

class ImportsourceTabs extends Tabs
{
    use TranslationHelper;

    protected $id;

    public function __construct($id = null)
    {
        $this->id = $id;
        $this->assemble();
    }

    public function activateMainWithPostfix($postfix)
    {
        $mainTab = 'index';
        $tab = $this->get($mainTab);
        $tab->setLabel($tab->getLabel() . ": $postfix");
        $this->activate($mainTab);

        return $this;
    }

    protected function assemble()
    {
        if ($id = $this->id) {
            $params = ['id' => $id];
            $this->add('index', [
                'url'       => 'director/importsource',
                'urlParams' => $params,
                'label'     => $this->translate('Import source'),
            ])->add('modifier', [
                'url'       => 'director/importsource/modifier',
                'urlParams' => ['source_id' => $id],
                'label'     => $this->translate('Modifiers'),
            ])->add('history', [
                'url'       => 'director/importsource/history',
                'urlParams' => $params,
                'label'     => $this->translate('History'),
            ])->add('preview', [
                'url'       => 'director/importsource/preview',
                'urlParams' => $params,
                'label'     => $this->translate('Preview'),
            ]);
        } else {
            $this->add('add', [
                'url'   => 'director/importsource/add',
                'label' => $this->translate('New import source'),
            ])->activate('add');
        }
    }
}
